# -*- coding: utf-8 -*-

#       icd_mirror.py   2011.11.26  kita
#!! パーツ反転操作補助 Script
#   必要ファイル
#     icd_mirror.py icd_mirror.dat  icd_module.py icd_mirror.pdf 

# 機能
#   ピックした部品を「基準面」を基準に反転する
#   「基準面」とは重心を含む面
# 参考  SxEnt\Mirror\Mirror.cs
#       SxWF\GetPartList\GetPartList.cs　
#       SxSys\ClearUndo\ClearUndo.cs

#   履歴
# 2022.1.9      「なんでも」「各個」を追加
#               他のコマンド選択で反転作業を終了するようにした
#               get_part()  GO、他コマンド -> None      パーツ以外 -> False     
# 2022.2.18     子パーツ内のボルトへの対応（金子さん対策) 階層構造をもったボルト類(E.X. スタッドの立った部品等)
#                   バネ座金:反転   その他:Rename
#                   親パーツが「1製作」の場合は飛ばす        
#               「ほぼ対称形部品」への対応
#                   「図芯を通る平面」での反転を追加..しようかなー...
#                   重心位置座標(部品図)が怪しい(1/100mm以下の端数をもつ）場合に警告を出す。
#               座標表示（直交座標、極座標）


import clr
clr.AddReference('sxnet')
from sxnet import *
import sys
import os
import codecs
import numpy as np
import tkinter as tk
import tkinter.ttk as ttk
import re
import icd_module as imd   # iCAD関連のモジュール群
import subprocess
import my_module as mmd     # divmod2用 
import my_vector as mvc     # mvc.v2p3(v3) 

SxSys.init(3999)

os.system('cls')



lmt = 0.05   # 重心座標のチェック用 divmod2(x, lim, 6)
lmt2 = 1/100000 # 
#col0 = mmd.Color.GREEN; col1 = mmd.Color.END
c0 = mmd.Color.WHITE; c1 = mmd.Color.GREEN; c2 = mmd.Color.END
c3 = mmd.Color.RED
c4 = mmd.Color.REVERCE

print('\n   %s作業内容を選択後「実行」ボタンを押して下さい%s' % (c1, c2))
#print('\n   %s作業内容を選択後「実行」ボタンを押して下さい%s' % (c4, c2))

def bolt_check(part):   # partがボルト類なら True、 以外なら False
    inf = part.getInfDetail()
    if inf.is_external == True : # 外部パーツは飛ばす
        return False
    
    for ss in mirror_bolt_lst:
        if inf.name.find(ss) > -1 or inf.comment.find(ss) > -1:
            return True
    
    return False

# 反転したボルト類を反転する
def mirror_mbolt(part): # 座金は反転その他のボルト類あはRename    
    inf = part.getInfDetail()
    if inf.is_mirror == True:       #反転してる
        prnt_part = part.getParent()
        if prnt_part != None: 
            #print('親パーツが外部パーツです')
            if imd.kubun_is(prnt_part) == '1製作':  #親パーツ区分が「1製作」の場合飛ばす
                print('製作部品 %s の付属ボルト類です' % prnt_part.getInfDetail().name)
                return

        #if v_renm_mir.get() == 0:   # Rename
        #    mirror_rename(part)

        if inf.name.find('ばね座金') > -1:  #反転
            v0 = np.array([inf.cs.org.x, inf.cs.org.y, inf.cs.org.z])     #原点
            pos0 = SxPos(v0[0], v0[1], v0[2])
            # いよいよ反転
            part.mirror(inf.cs.org, inf.cs.xvec)  # 原点、反転平面法線ベクトル(yz平面で反転)
            print('%s\n   %s を 反転 しました%s' % (c1, inf.name, c2))

        else:   #座金以外　rename
            mirror_rename(part)

        if v_disp.get() == True:
            part.setVisible(False)   # パーツを非表示



def ses_check(part):    # SES部品かどうかの判定
    inf = part.getInfDetail()
    ss1 = re.search('A[A-Z][A-Z]', inf.name)    #[A]で始まり2,3桁目はアルファベット
    if ss1 != None and len(inf.name) == 12: #SES部品判定
        return True
    else:
        return False

# 反転したSES部品をRename(各個)
def mirror_ses(part):
    inf = part.getInfDetail()
    if inf.is_external == True : # 外部パーツは飛ばす
        return
    #print(inf.name)

    if ses_check(part): #SES部品判定

        if inf.is_mirror == True:       #反転してる
            if part.getParent() != None:     #親パーツが存在する場合も飛ばす
                #print('親パーツが外部パーツです')
                print('親パーツが存在します')
                return

            #if v_renm_mir.get() == 0:   # Rename
            mirror_rename(part)
            print('\n   %s を Rename しました' % inf.name)
            if v_disp.get() == True:
                part.setVisible(False);     # パーツを非表示


    else:
        if v_one_all.get() == 0:  #各個 
            print('\n   %sはSES部品ではありません' % inf.name)

def check_ses_mirror(part):     # 反転形のあるSES部品かどうか
    inf = part.getInfDetail()
    mpart_name = None
    for mses in mirror_ses_lst:
        if mses[0].find(inf.name) > -1: # あった
            mpart_name = mses[1]
        elif mses[1].find(inf.name) > -1: # あった
            mpart_name = mses[0]
    
    return mpart_name   # 反転形が無かったらNone


# 指定されたパーツ（要素）を指定された法線ベクトルで重心を原点に反転する
def mirror_part(part,vec):
    #print(type(edge))
    inf = part.getInfDetail()
    opt_mass = SxOptMass()
    mass = part.getMass(opt_mass)
    part.mirror(mass.pos, vec)
    print('%s\n   %s を 反転 しました%s' % (c1, inf.name, c2))
    #print('%s\n   %s を 反転 しました%s' % (col0, inf.name, col1))
  
# 指定されたパーツをリネームする
def mirror_rename(part):
    inf = part.getInfDetail()
    name0 = inf.name
    name1 = name0 + '_'
    part.setName(name1, inf.comment, None, False) 
    part.setName(name0, inf.comment, None, False) 
    print('\n   %s を Rename しました' % name0)
    if v_disp.get() == True:
        part.setVisible(False);     # パーツを非表示



def push_disp():     # 反転部品だけを表示
      #WF内の全パーツ取得 
      model = SxModel.getActive()
      wf = model.getGlobalWF()
      parts = wf.getPartList()
      if parts == None:
          print('\n パーツが存在しません\007\n')
          return

      for part in parts:
        inf = part.getInfDetail()
        if inf.is_mirror == False:       #反転してない
           part.setVisible(False);     # パーツを非表示

      print('\n     非反転部品を非表示にしました')


#-----------------------------------------------------------
#   パーツ重心のチェック　OK:True  NG:False
#-----------------------------------------------------------
def cg_check(part): # パーツ重心のチェック
    opt_mass = SxOptMass()
    mass = part.getMass(opt_mass)   #重心
    cgx = mass.pos.x
    cgy = mass.pos.y
    cgz = mass.pos.z
    (dx, mx) = mmd.divmod2(cgx, lmt, 6) # 小数点6以下丸めた値の商と余り
    (dy, my) = mmd.divmod2(cgy, lmt, 6)
    (dz, mz) = mmd.divmod2(cgz, lmt, 6)
    #mx = abs(mx); my = abs(my); mz = abs(mz);
    #lmt2 = lmt/1000
    #print('余り x,y,z = %10.10f %10.10f %10.10f' % (mx, my, mz))
    # x,y,z座標のうち2つ以上が端数値(0.1未満)を有する
    if mx == 0:
        ssx = '%s%4.6f%s' % (c0,cgx,c2)
    else:
        ssx = '%s%4.6f%s' % (c1,cgx,c2)
    if my == 0:
        ssy = '%s%4.6f%s' % (c0,cgy,c2)
    else:
        ssy = '%s%4.6f%s' % (c1,cgy,c2)
    if mz == 0:
        ssz = '%s%4.6f%s' % (c0,cgz,c2)
    else:
        ssz = '%s%4.6f%s' % (c1,cgz,c2)

    v3 = np.array([cgx,cgy,cgz])
    (p_rad, p_deg) = mvc.v2p3(v3)
    (dr,mr) = mmd.divmod2(p_deg[0], 0.1, 5)
    #(dt,mt) = mmd.divmod2(p_deg[1], 0.1, 6)
    #(df,mf) = mmd.divmod2(p_deg[2], 0.1, 6)
    (dt,mt) = mmd.divmod2(360.0,p_deg[1], 5)
    (df,mf) = mmd.divmod2(360.0,p_deg[2], 5)

    print(mt,p_deg[1]) #!!!

    if mr == 0:
        ssr = '%s%4.5f%s' % (c0,p_deg[0],c2)
    else:
        ssr = '%s%4.5f%s' % (c1,p_deg[0],c2)
    if mt == 0:
        sst = '%s%4.5f%s' % (c0,p_deg[1],c2)
    else:
        sst = '%s%4.5f%s' % (c1,p_deg[1],c2)
    if mr == 0:
        ssf = '%s%4.5f%s' % (c0,p_deg[2],c2)
    else:
        ssf = '%s%4.5f%s' % (c1,p_deg[2],c2)
        
    print('xyz = %s %s %s  rθφ= %s %s %s' % (ssx, ssy, ssz, ssr, sst, ssf))


    if mx == 0.0 or my == 0.0 or mz == 0.0 or mr == 0 or mt == 0 or mf ==0 :
        #print('\n   部品図の重心座標 x = %10.10f y = %10.10f  z = %10.10f\n' % (cgx, cgy, cgz))
        return True
    else:
        mmd.winbeep()
        #os.system('cls')
        #print('余り x,y,z = %10.10f %10.10f %10.10f' % (mx, my, mz))
        #print('\007')
        #print('\n%s   部品図の重心座標 x, y, z = %10.10f  %10.10f  %10.10f %s\007\n' % (col0, cgx, cgy, cgz, col1))
        return False

#-----------------------------------------------------------
#   製作部品パーツを反転　重心を含むxy,yz,zx平面順次切り替え方式
#-----------------------------------------------------------
def mirror_prdct_part(): #製作パーツを反転 
    opt.select_pos = True
    loop = True
    while loop:     # パーツ選択
        print("\n\n  パーツをピックして下さい。(空間ピックで次の面。GOで確定)")
        part = get_part()
        #(part, flg_ext) = get_part()
        if part == None:   #GO  終了
            print('\n   %s の反転を終了しました' % inf_dt.name) 
            break
        elif part == False:  # パーツではない
            print('\n   パーツではありません\007')
            continue
        inf_dt = part.getInfDetail()
        if inf_dt.is_mirror == False:       #反転してない部品
            print('\n    %s は反転してません\007\n' % inf_dt.name)
            continue
        #if not inf_dt.is_external: # 内部部パーツ
        #    print('     %s は内部パーツです\007\n' % inf_dt.name)
        #    continue

        # 重心の座標チェック
        if not cg_check(part):
            #print('\n   部品図の重心座標 x, y, z = %10.10f  %10.10f  %10.10f\007\n' % (cgx, cgy, cgz))
            #print('\007')
            yn = input('    怪しい部品ですが処理を続けますか y/n(Enter)   ')
            if yn == 'n' or yn == '':
                loop = False
                break

        cnt = 0
        face_num = 0 
        #pre_name = ' '; pre_pos = [99.999, 0.0, 0.0]

        opt.select_ent = False
        opt.select_pos = True
        loop1 = True

        while loop1:    # 反転面切り替え
            if face_num == 0:
                vec = inf_dt.cs.xvec
                print('     y-z面で反転します')
            elif face_num == 1:
                vx = np.array([inf_dt.cs.xvec.x, inf_dt.cs.xvec.y, inf_dt.cs.xvec.z])
                vz = np.array([inf_dt.cs.zvec.x, inf_dt.cs.zvec.y, inf_dt.cs.zvec.z])
                vec0 = np.cross(vx,vz)     # 法線ベクトル
                vec = SxVec(vec0[0], vec0[1], vec0[2])  
                print('     x-z面で反転します')
            elif face_num == 2:
                vec = inf_dt.cs.zvec
                print('     x-y面で反転します')
    
            elif face_num == 3: #どれもはずれ
                #SxSys.command(";UNDO", False)
                print('\n   %s はシンメトリック部品ではないようです\007\n' % inf_dt.name)
                break
            # 反転実施
            opt.select_pos = True
            mirror_part(part, vec)
            #cnt+=1
            
            inf = SxSys.select(opt)
            if inf.status == SxInfSelect.STATUS_POS:  # 空間ピックで次の面
                SxSys.command(";UNDO", False)
                cnt+=1
                face_num = cnt % 4
            elif inf.status == SxInfSelect.STATUS_GO:     # GO
                print('\n    反転完了しました\007')
                if v_disp.get() == True:
                    part.setVisible(False);     # 反転済みパーツ（マーク無し)を非表示
                break



def get_part(): # マウスピックされたパーツを返す(各個)
    opt.select_ent = True
    opt.select_pos = False
    inf = SxSys.select(opt)
    if inf == None: return
    if inf.status == SxInfSelect.STATUS_GO: #終了
        part = None

    elif inf.status == SxInfSelect.STATUS_ENT :
        try:
            part = inf.ent
            inf_dt = part.getInfDetail()
        except:
            print('     パーツではありません')
            part = False
            
    else:   # Ent以外
        part = None

    return part

def tc_bolt():  # Bolt処理(Take Care)
    #print(v_one_all.get())
    #if v_renm_mir.get() == 0:   #Rename
        #print('     金子さんに叱られますが...')

    if v_one_all.get() == 0:  #各個
        loop = True
        while loop:
            part = get_part()
            inf_dt = part.getInfDetail()
            #(part, flg_ext) = get_part()
            if part == False:    # パーツ以外
                continue
            elif part == None: # GO選択 or 他コマンド
                break
            if inf_dt.is_external : # 外部パーツ
                print('     %s は外部パーツです' % part.getInfDetail().name)
                continue
            if bolt_check(part):    # ボルト類なら 
                mirror_mbolt(part)
            else:
                print('     ボルト類ではありません')

                
    else:   # 一括
        part_lst = wf.getPartList()   # 全ての3次元パーツを取得
        for part in part_lst:
            if bolt_check(part):    # ボルト類なら
                mirror_mbolt(part)

    print('\n   ボルト反転を終了しました\007\n')
            

def tc_ses():   #SES部品処理(内部パーツ) rb_rm(Rename-mirror Radiobutton)無効
    # Renameのみ有効

    if v_one_all.get() == 0:  #各個
        loop = True
        while loop:
            part = get_part()
            #(part, flg_ext) = get_part()
            if part == False:    # パーツ以外
                continue
            elif part == None: # Go選択 or 他コマンド
                break
            
            inf_dt = part.getInfDetail()
            if inf_dt.is_mirror == False: # 反転済み
                print('     %s は反転マークがありません' % inf_dt.name)
                continue
            if inf_dt.is_external : # 外部パーツ
                print('     %s は外部パーツです' % inf_dt.name)
                continue
            
            mpart_zuban = check_ses_mirror(part)  #反転形図番 無し:None
            if mpart_zuban != None: # 反転形図番あり
                imd.set_pf_zuban(part, mpart_zuban) # パーツ名、pf情報設定
                if v_disp.get() == True:
                    part.setVisible(False);     # パーツを非表示
                print('     %s を %sに書き換えました\n' % (inf_dt.name, mpart_zuban))
            else:        
                mirror_ses(part) # Rename

    else:   # 一括
        part_lst = wf.getPartList()   # 全ての3次元パーツを取得
        for part in part_lst:
            inf_dt = part.getInfDetail()
            if inf_dt.is_mirror == False: # 反転済み
                #print('     %s は反転マークがありません' % inf_dt.name)
                continue

            mpart_zuban = check_ses_mirror(part)  #反転形図番 無し:None
            if mpart_zuban != None: # 反転形図番あり
                imd.set_pf_zuban(part, mpart_zuban) # パーツ名、pf情報設定
                if v_disp.get() == True:
                    part.setVisible(False);     # パーツを非表示
                print('     %s を %sに書き換えました\n' % (inf_dt.name, mpart_zuban))
            else:
                mirror_ses(part)

    print('\n   SES部品の反転(Rename)を終了しました\007\n')

def tc_kounyu():   #etc部品(購入品等)処理
    print('\n   反転形の購入品にはくれぐれも注意してください\007\n')

    if v_one_all.get() == 0:  #各個
        loop = True
        while loop:
            part = get_part()
            if part == False:    # パーツ以外
                continue
            elif part == None: # Go選択 or 他コマンド
                break
            
            inf_dt = part.getInfDetail()
            if inf_dt.is_external: # 外部パーツ
                print('     %s は外部パーツです' % inf_dt.name)
                continue
            if inf_dt.is_mirror == False: # 反転済み
                print('     %s は反転マークがありません' % inf_dt.name)
                continue

            if bolt_check(part):
                print('     %s はボルトです' % inf_dt.name)
                continue
            if ses_check(part):
                print('     %s はSES部品です' % inf_dt.name)
                continue
            
            p_part = part.getParent()
            if p_part != None:
                pp_inf = p_part.getInfDetail()   # 親パーツ情報
                if pp_inf.is_external == True:   # 親パーツが外部パーツ
                    print('     %s は部品図の一部です(たぶん)' % inf_dt.name)
                    continue
                
            if imd.kubun_is(part) == '2購入':
                mirror_rename(part)


    else:   # 一括
        part_lst = wf.getPartList()   # 全ての3次元パーツを取得
        for part in part_lst:
            if part == None:    # パーツ以外
                continue
            inf_dt = part.getInfDetail()
            if inf_dt.is_external == False and inf_dt.is_mirror == True:    #反転した内部パーツ
                if bolt_check(part):
                    continue
                if ses_check(part):
                    continue
                p_part = part.getParent()
                if p_part != None:
                    pp_inf = part.getParent().getInfDetail()   # 親パーツ情報
                    if pp_inf.is_external == True:   # 親パーツが外部パーツ
                        continue
                
                if imd.kubun_is(part) == '2購入':
                    mirror_rename(part)

    print('\n   購入品の Rename を終了しました\007\n')


def tc_ext():   #製作部品パーツ(部品図)処理
    mirror_prdct_part()

    print('\n   製作部品の反転を終了しました\007\n')


def tc_all():  # なんでも処理(Take Care)
    loop = True
    while loop:
        part = get_part()
        #part, flg_ext = get_part()
        #(part, flg_ext) = get_part()
        if part == False:    # パーツ以外
            print('     パーツではありません\007\n')
            continue
        elif part == None: # GO選択 or 他コマンド
            break

        inf_dt = part.getInfDetail()
        if inf_dt.is_external: # 外部パーツ
            print('     %s は外部パーツです\007\n' % part.getInfDetail().name)
            continue
        if inf_dt.is_mirror == False: # 反転済み
            print('     %s は反転マークがありません\007\n' % inf_dt.name)
            continue
        #if bolt_check(part):    # ボルト類なら 
        #    mirror_mbolt(part)
        else:
            mirror_rename(part)


def push_exe():
    global wf
    # Activeな3D空間のwfインスタンス作成
    wf = SxWF.getActive() 
    print('\n     反転(Rename)作業を開始します\n')
    if v_parts_type.get() == 0: # bolt
        tc_bolt()   # Take Care Bolt
    elif v_parts_type.get() == 1: # SES
        tc_ses()   # Take Care SES
    elif v_parts_type.get() == 2: # etc
        tc_kounyu()   # Take Care 購入品
    elif v_parts_type.get() == 3: # 外部パーツ（製作部品）
        tc_ext()   #
    elif v_parts_type.get() == 4: # なんでも
        tc_all()   #


def push_help():
    cmd = 'icd_mirror.pdf'
    result = subprocess.call(cmd,shell=True)          

#-------------------------------------------
# パーツ種類ラジオボタンが押されたときの処理
#-------------------------------------------
def rbtn_choice():  # Raio Button選択Ivent
    if v_parts_type.get() == 0: #ボルト類
        parts_type = 'bolt'
        v_renm_mir.set(0)   # Rename
        v_one_all.set(1)    # 一括
        #rb_rm[0]['state'] = tk.NORMAL   #Rename 
        #rb_rm[1]['state'] = tk.NORMAL   #mirror
        rb_rm[0]['state'] = tk.DISABLED   #Rename 
        rb_rm[1]['state'] = tk.DISABLED   #mirror
        rb_oa[0]['state'] = tk.NORMAL   #各個有効
        rb_oa[1]['state'] = tk.NORMAL   #一括有効
    elif v_parts_type.get() == 1:   # SES部品
        parts_type = 'ses'
        v_renm_mir.set(0)   # Rename
        v_one_all.set(1)    # 一括
        rb_rm[0]['state'] = tk.NORMAL   #Rename
        rb_rm[1]['state'] = tk.DISABLED #mirror
        rb_oa[0]['state'] = tk.NORMAL   #各個有効
        rb_oa[1]['state'] = tk.NORMAL   #一括有効
    elif v_parts_type.get() == 2:   # 購入品等
        parts_type = 'etc'
        v_renm_mir.set(0)
        v_one_all.set(0)    # 各個    
        rb_rm[0]['state'] = tk.NORMAL   #Rename
        rb_rm[1]['state'] = tk.DISABLED   #mirror
        rb_oa[0]['state'] = tk.NORMAL   #各個有効
        rb_oa[1]['state'] = tk.NORMAL   #一括有効
    elif v_parts_type.get() == 3:   #製作品(部品図)
        parts_type = 'ext'
        v_renm_mir.set(1)
        v_one_all.set(0)
        rb_rm[0]['state'] = tk.DISABLED 
        rb_rm[1]['state'] = tk.NORMAL 
        rb_oa[0]['state'] = tk.NORMAL   #各個
        rb_oa[1]['state'] = tk.DISABLED #一括無効
    elif v_parts_type.get() == 4:   #なんでも
        parts_type = 'all'
        v_renm_mir.set(0)   # Rename
        v_one_all.set(0)    # 各個
        rb_rm[0]['state'] = tk.NORMAL 
        rb_rm[1]['state'] = tk.DISABLED 
        rb_oa[0]['state'] = tk.NORMAL   #各個
        rb_oa[1]['state'] = tk.DISABLED #一括無効

    #print('パーツ種類: %s' % parts_type)

    return parts_type

def on_closing():
    print('\n   ミラー反転処理を終了しました\n')
    root.destroy()

# 起動時にSES反転部品一覧、ボルト類品名一覧を読み込む
fn = 'icd_mirror.dat'
flg = 0
if os.path.exists(fn):    # File存在確認
    fp = codecs.open(fn, 'r', 'utf-8')
    lines = fp.readlines()
    fp.close()
    i1 = 0; i2 = 0
    mirror_ses_lst = []     # 反転形のSES部品リスト Global
    mirror_bolt_lst = []     # ボルト類リスト Global
    for line in lines:
        line = line.rstrip()    # 行末の改行削除
        if line == '' or line == ' ':
            continue
        if line.find('SES部品') > -1:  # 「SES部品」が含まれてるなら
            flg = 1
            continue
        if line.find('ボルト類') > -1:  # 「ボルト類」が含まれてるなら
            flg = 2
            continue

        if flg == 1: 
            tmp = line.split(',') 
            mirror_ses_lst.append(tmp)
            #print(tmp)
            i1 += 1    
        if flg == 2: 
            #tmp = line.split(',') 
            mirror_bolt_lst.append(line)
            #print(line)
            i2 += 1    
    
 

#print(mirror_ses)  # mirror_sesはglobal


# マウスピック準備
opt = SxOptSelect()
#opt.ent_mode = SxSys.ENTMODE_MULTI
opt.ent_mode = SxSys.ENTMODE_PART
opt.select_ent = True
opt.select_pos = False
opt.select_seg = False
opt.select_go = True

# Activeな3D空間のwfインスタンス作成
#wf = SxWF.getActive() 

#************************************
# ボタン等の部品配置
#************************************
nl = 5
root = tk.Tk()
root.attributes("-topmost", True)    # 常に前面に表示
root.configure(bg='RoyalBlue4')
root.title('パーツ反転処理Ver.1.0')   #タイトル
root.geometry('300x%d+1000+0' % (nl*33))
style = ttk.Style()    #Default
style.theme_use('winnative')

btn_bcol = 'grey21'     #ボタン背景色
btn_tcol = 'white'      #ボタン文字色

label_bcol = 'khaki3'   #ラベル背景色
label_tcol = 'black'   #ラベル文字色
e_bcol = 'khaki4'

x00 = 10; y00 = 4
dx = 100;  dy = 25
wdth = 10 

# PartsTypeラジオボタン用
v_parts_type = tk.IntVar()
v_parts_type.set(0)

# Rename or Mirrorラジオボタン用
v_renm_mir = tk.IntVar()
v_renm_mir.set(0)

# 各個、一括ラジオボタン用
v_one_all = tk.IntVar()
v_one_all.set(1)

# 表示、非表示チェックボタン用
v_disp = tk.BooleanVar()
v_disp.set(True)


# ボタン類の配置
f0 = ttk.LabelFrame(root, text = 'パーツ種類')
f1 = ttk.LabelFrame(root, text = '処理内容')
f2 = ttk.LabelFrame(root, text = '処理方法')
f3 = ttk.LabelFrame(root, text = '反転済み')

txt0 = ['ボルト類', 'SES部品','購入品','製作品','なんでも']
for i in range(len(txt0)):
    ttk.Radiobutton(f0, text = txt0[i],value = i, variable = v_parts_type, command=rbtn_choice).pack()  

rb_rm = []     # Rename, mirror用 Radiobutton List 
txt1 = ['ReName','反  転'];
for i in range(len(txt1)):
    rb_rm.append(ttk.Radiobutton(f1, text = txt1[i],value = i, variable = v_renm_mir))
    rb_rm[i].pack()

rb_rm[0]['state'] = tk.DISABLED   #Rename 
rb_rm[1]['state'] = tk.DISABLED   #mirror

rb_oa = []
txt2 = ['各個','一括'];
for i in range(len(txt2)):
    rb_oa.append(ttk.Radiobutton(f2, text = txt2[i],value = i, variable = v_one_all))
    rb_oa[i].pack()  

ttk.Checkbutton(f3, text = '非表示', variable = v_disp).pack()

pdx = 1; pdy = 1; dx = 80; dy = 5
#f0.pack(padx = pdx, pady = pdy, side = tk.LEFT)
#f1.pack(padx = pdx, pady = pdy, side = tk.LEFT)
#f2.pack(padx = pdx, pady = pdy, side = tk.LEFT)
#f3.pack(padx = pdx, pady = pdy, side = tk.TOP)
f0.place(x=5, y=dy)
f1.place(x=85, y=dy)
f2.place(x=160, y=dy)
f3.place(x=230, y=dy)

#ss = '反転済パーツ'
ss = '反転済パーツ'
label = tk.Label(root,text=ss ,bg=label_bcol)  #  Labelの作成
label.place(x=160, y=82)    #  Labelの位置

ss = '非表示'   # Buttn
btn_exe = tk.Button(root,text = ss,command = push_disp, bg=btn_bcol, fg=btn_tcol) #ボタンの作成
btn_exe.place(x=160,y=104)

ss = '実行'   # 実行Buttn
btn_exe = tk.Button(root,text = ss,command = push_exe, bg=btn_bcol, fg=btn_tcol) #ボタンの作成
btn_exe.place(x=250,y=104)

ss = 'ヘルプ'   # ヘルプButton
btn_help = tk.Button(root,text = ss,command = push_help,bg=btn_bcol,fg=btn_tcol) 
btn_help.place(x=250,y=65)


#root.attributes("-toolwindow",1)    # 最小、最大化ボタン非表示
root.protocol("WM_DELETE_WINDOW", on_closing)
root.mainloop()

